Thread (34 messages) 34 messages, 4 authors, 2011-06-04
STALE5500d

[RFC PATCH 23/27] mac80211: rename ieee80211_sdata_state_bits to mac80211_sdata_state_bits

From: Kalle Valo <hidden>
Date: 2011-05-29 20:06:50
Subsystem: mac80211, the rest · Maintainers: Johannes Berg, Linus Torvalds

Signed-off-by: Kalle Valo <redacted>
---
 net/mac80211/mac80211_i.h |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/net/mac80211/mac80211_i.h b/net/mac80211/mac80211_i.h
index 5ae43dc..dfc3f77 100644
--- a/net/mac80211/mac80211_i.h
+++ b/net/mac80211/mac80211_i.h
@@ -524,14 +524,14 @@ enum mac80211_sub_if_data_flags {
 };
 
 /**
  * enum ieee80211_sdata_state_bits - virtual interface state bits
  * @SDATA_STATE_RUNNING: virtual interface is up & running; this
  *	mirrors netif_running() but is separate for interface type
  *	change handling while the interface is up
  * @SDATA_STATE_OFFCHANNEL: This interface is currently in offchannel
  *	mode, so queues are stopped
  */
-enum ieee80211_sdata_state_bits {
+enum mac80211_sdata_state_bits {
 	SDATA_STATE_RUNNING,
 	SDATA_STATE_OFFCHANNEL,
 };
@@ -524,14 +524,14 @@ enum mac80211_sub_if_data_flags {
 
 /**
- * enum ieee80211_sdata_state_bits - virtual interface state bits
+ * enum mac80211_sdata_state_bits - virtual interface state bits
  * @SDATA_STATE_RUNNING: virtual interface is up & running; this
  *	mirrors netif_running() but is separate for interface type
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help